@@ -3,7 +3,10 @@ import glob
 import os
 from os.path import dirname, exists, isdir, join, relpath
 
-from mmcv import Config
+import numpy as np
+from mmengine import Config
+from mmengine.dataset import Compose
+from mmengine.registry import init_default_scope
 from torch import nn
 
 from mmseg.models import build_segmentor
@@ -28,7 +31,7 @@ def test_config_build_segmentor():
     """Test that all segmentation models defined in the configs can be
     initialized."""
     config_dpath = _get_config_directory()
-    print('Found config_dpath = {!r}'.format(config_dpath))
+    print(f'Found config_dpath = {config_dpath!r}')
 
     config_fpaths = []
     # one config each sub folder
@@ -39,20 +42,20 @@ def test_config_build_segmentor():
     config_fpaths = [p for p in config_fpaths if p.find('_base_') == -1]
     config_names = [relpath(p, config_dpath) for p in config_fpaths]
 
-    print('Using {} config files'.format(len(config_names)))
+    print(f'Using {len(config_names)} config files')
 
     for config_fname in config_names:
         config_fpath = join(config_dpath, config_fname)
         config_mod = Config.fromfile(config_fpath)
 
         config_mod.model
-        print('Building segmentor, config_fpath = {!r}'.format(config_fpath))
+        print(f'Building segmentor, config_fpath = {config_fpath!r}')
 
         # Remove pretrained keys to allow for testing in an offline environment
         if 'pretrained' in config_mod.model:
             config_mod.model['pretrained'] = None
 
-        print('building {}'.format(config_fname))
+        print(f'building {config_fname}')
         segmentor = build_segmentor(config_mod.model)
         assert segmentor is not None
 
@@ -66,31 +69,30 @@ def test_config_data_pipeline():
     CommandLine:
         xdoctest -m tests/test_config.py test_config_build_data_pipeline
     """
-    from mmcv import Config
-    from mmseg.datasets.pipelines import Compose
-    import numpy as np
 
+    init_default_scope('mmseg')
     config_dpath = _get_config_directory()
-    print('Found config_dpath = {!r}'.format(config_dpath))
+    print(f'Found config_dpath = {config_dpath!r}')
 
     import glob
     config_fpaths = list(glob.glob(join(config_dpath, '**', '*.py')))
     config_fpaths = [p for p in config_fpaths if p.find('_base_') == -1]
     config_names = [relpath(p, config_dpath) for p in config_fpaths]
 
-    print('Using {} config files'.format(len(config_names)))
+    print(f'Using {len(config_names)} config files')
 
     for config_fname in config_names:
         config_fpath = join(config_dpath, config_fname)
-        print(
-            'Building data pipeline, config_fpath = {!r}'.format(config_fpath))
+        print(f'Building data pipeline, config_fpath = {config_fpath!r}')
         config_mod = Config.fromfile(config_fpath)
 
         # remove loading pipeline
         load_img_pipeline = config_mod.train_pipeline.pop(0)
         to_float32 = load_img_pipeline.get('to_float32', False)
-        config_mod.train_pipeline.pop(0)
-        config_mod.test_pipeline.pop(0)
+        del config_mod.train_pipeline[0]
+        del config_mod.test_pipeline[0]
+        # remove loading annotation in test pipeline
+        del config_mod.test_pipeline[-2]
 
         train_pipeline = Compose(config_mod.train_pipeline)
         test_pipeline = Compose(config_mod.test_pipeline)
@@ -106,10 +108,10 @@ def test_config_data_pipeline():
             img=img,
             img_shape=img.shape,
             ori_shape=img.shape,
-            gt_semantic_seg=seg)
-        results['seg_fields'] = ['gt_semantic_seg']
+            gt_seg_map=seg)
+        results['seg_fields'] = ['gt_seg_map']
 
-        print('Test training data pipeline: \n{!r}'.format(train_pipeline))
+        print(f'Test training data pipeline: \n{train_pipeline!r}')
         output_results = train_pipeline(results)
         assert output_results is not None
 
@@ -118,9 +120,8 @@ def test_config_data_pipeline():
             ori_filename='test_img.png',
             img=img,
             img_shape=img.shape,
-            ori_shape=img.shape,
-        )
-        print('Test testing data pipeline: \n{!r}'.format(test_pipeline))
+            ori_shape=img.shape)
+        print(f'Test testing data pipeline: \n{test_pipeline!r}')
         output_results = test_pipeline(results)
         assert output_results is not None
 
